@@ -5,7 +5,7 @@ use v5.20;
 use Carp;
 
 use Exporter qw(import);
-our @EXPORT = qw(add_from_stdin);
+our @EXPORT_OK = qw(add_from_stdin);
 our $VERSION = 'unstable';
 
 =head1 NAME
@@ -33,23 +33,27 @@ sub delete_elements {
 
     # Remove indices from end of array first
     for (sort { $b <=> $a } @indices) {
-	splice @{$array_ref}, $_, 1;
+        splice @{$array_ref}, $_, 1;
     }
 }
 
+=head2 add_from_stdin()
+
+=cut
+
 sub add_from_stdin {
     my ($array_ref, $tokens) = @_;
     my @indices;
 
     for my $idx (0..@{$array_ref}-1) {
-	my $match = grep { $array_ref->[$idx] eq $_ } @{$tokens};
-	push(@indices, $idx) if $match > 0;
+        my $match = grep { $array_ref->[$idx] eq $_ } @{$tokens};
+        push(@indices, $idx) if $match > 0;
     }
 
     if (scalar @indices > 0) {
-	delete_elements($array_ref, @indices);        
+        delete_elements($array_ref, @indices);
 
-	push(@{$array_ref}, <STDIN>);  # add arguments from stdin
+        push(@{$array_ref}, <STDIN>);  # add arguments from stdin
         chomp(@{$array_ref});          # remove newlines
     }
 }
